---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Please search issues in https://github.com/skodaconnect/skodaconnect and https://github.com/skodaconnect/homeassistant-skodaconnect for duplicates or fixes before reporting a new issue.**

**Describe the bug**
A clear and concise description of what the bug is.

**Is this working in MySkoda app?***
Logout and login in the MySkoda app, preferably on Android.
Make sure that you have the latest app updates, sometimes there's new consent needed that will only show in latest app version.

**Latest working release**
If the problem started after updating to a new release, please state latest working release.

**Debug logs**
If applicable, add debug logs. See [README](https://github.com/skodaconnect/homeassistant-skodaconnect#enable-debug-logging) on how to enable debug logs with response debugging.

**Installation:**
 - Home Assistant variant: [e.g. Hass OS, Docker, Core, Supervised]
 - Python version [e.g. 3.7, 3.8]
 - Python library versions ["python3 -m pip list"]

**Additional context**
Add any other context about the problem here.
